function [Tab_r, Tab_K] = segmentation(y, p, Nmc, step)

%------------------------------------------------------------------
% JOINT SEGMENTATION PROCEDURE FOR AR PROCESSES
% by N. DOBIGEON and J.-Y. TOURNERET 
% IRIT/ENSEEIHT/TSA - France - 2005
% 
% INPUT
%       y    : the signal to be segmented
%       p    : order of the AR processes
%       Nmc   : number of MCMC iterations
%       step : Sampling step. By default equal to 1. 
%              Can be increased to accelerate the procedure
%
% OUTPUT
%       Tab_r : the samples R(t) generated by the procedure
%       Tab_K : the corresponding samples K(t)
%
%------------------------------------------------------------------

global J N Tepsilon

% signals parameters
% J = number of sequence
% N = length of the signal
[ J N ] = size(y);

% BEGINNING OF THE SEGMENTATION
disp(' ');
disp('BEGINNING OF THE SEGMENTATION');
tic;

% initialization of the parameters
    r = [zeros(J,N-1) ones(J,1)];
    sigma2 = 5;
    a = 5;
    
    % parameters of f(sigma2|nu, gam)
    nu = 2;
    gam = 2;

    % parameters de f(a|sigma2, delta02, p)
    delta02 = 1;
    
   
% initialization of the hyper-hyperparameters
    % parameters de f(P|alpha)
    alpha = ones(1,2^J);
     
    % parameters of f(delta02|zeta, beta)
    beta = 100;
    xi = 1;
    
   
% Tepsilon : all the abrupt change configurations
    eps_str=[];
    for i = 1:2^J
        eps_str = [eps_str' dec2bin(i-1,J)']';
    end
    for i = 1:2^J
        for j = 1:J
            Tepsilon(j,i) = strcmp(eps_str(i,j),'1');
        end
    end

    
% initialization of the AR's with p 0's
y = [zeros(J,p) y];


% output : MCMC states
Tab_r = zeros(J,N,Nmc);
Tab_K = zeros(J,Nmc);
	
h = waitbar(0,['Segmentation...'],'CreateCancelBtn','closereq', 'name', 'Segmentation');

for m_compt = 1:Nmc
    
     waitbar(m_compt/Nmc,h)

    % GENERATION OF R ACCORDING TO f(R|y,...)
    
        % pas d'chantillonnage
        r = sample_r(r,p,gam,delta02,alpha,nu,xi,beta,y,step);
        K = sum(r,2);
        K_max = max(K);
        Tab_r(:,:,m_compt) = r;
        Tab_K(:,m_compt) = K;
    
        
    % GENERATION OF (gam,delta02) ACCORDING TO f(gam,sigma2|...)

        [gam delta02] = sample_gam_delta02(r,p,gam,delta02,nu,xi,y);
      
   
end

% fin de l'algo
t_1 = toc;
% END OF THE SEGMENTATION
disp('END OF THE SEGMENTATION');
disp(['Execution time : ' num2str(t_1)]);

close(h)



        
        
        
    
        
