function result = exploitation(y, Tab_r, Tab_K, Nbi, Nr);

%------------------------------------------------------------------
% This function allows to exploit the results provided by
%       the function segmentation
% 
% INPUT
%       y     : the signal to be segmented
%       Tab_r : The MCMC samples R generated by the Gibbs sampling
%       Tab_K : The corresponding MCMC samples K
%       Nbi   : number of burn-in iteration
%       Nr    : number of iterations of interest
%
% OUTPUT
%       result : 1 if the function is correctly used, 0 otherwise
%
%------------------------------------------------------------------

result = 0;

[J N iteration] = size(Tab_r);

close all

% MMSE estimate of R
r_est(1:J,1:N) = reshape(mean(Tab_r(:,:,Nbi+1:end),3),J,N);


% MAP estimate of K
for j=1:J
    val_min(j) = min(Tab_K(j,Nbi+1:end))-1;
    val_max(j) = max(Tab_K(j,Nbi+1:end))+1;
    nb_val(j) =  val_max(j)-val_min(j)+1;
end

nb_val_max = max(nb_val);
K_est = zeros(J,nb_val_max);
min_val = max([min(val_min) 1]);
max_val = max(val_max);
tab_val = min_val:max_val;
for j=1:J
    K_est(j,min_val:max_val) = hist(Tab_K(j,Nbi+1:end),tab_val)/Nr;
end


% plot : R
figure(1);
for j=1:J
    subplot(2*J,1,2*j-1)
    plot(y(j,:));
    axis([1 N min(y(j,:))*1.1 max(y(j,:))*1.1])
    ylabel(['y_' int2str(j) '(n)']);
    %title(['Signal y_' int2str(j)]);
    subplot(2*J,1,2*j)
    bar(r_est(j,:));
    ylabel(['f(r_' int2str(j) '|y)']);
    %title(['Posterior distributions of r_' int2str(j)]);
    grid on;
    axis([1 N 0 1])
end

% plot : K
figure(2);
for j=1:J
    subplot(J,1,j)
    bar(K_est(j,:))
    axis([min_val max_val 0 1])
    xlabel(['K_' int2str(j)]);
    ylabel(['f(K_' int2str(j) '|y)']);
    %title(['Posterior distribution of K_' int2str(j)]);
end

% change-point detection
figure(1);
tp_r = 1:N;
for j=1:J
    [tp1 i] = max(K_est(j,:));
    nb_rupt = i;
    proba_rupt = r_est(j,:);
    [tp2 index] = sort(proba_rupt);
    index_rupt = tp_r(index(N-nb_rupt+1:N));
    
    % plot
    subplot(2*J,1,2*j-1)
    hold on
    for rupt=1:nb_rupt
        plot([index_rupt(rupt) index_rupt(rupt)], [min(y(j,:)) max(y(j,:))]*1.1,'r-.')
    end
    hold off
end

result=1;
